Exposure to biological substances is prevented or controlled. | OiRA

Help

1. Preparation
2. Involve
3. Identification + Evaluation
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Other risks
   - Unanswered
   - Postponed
   - Risk identified
   - Risk with measures
4. Action Plan
5. Report
6. Status 0%

Help

## Exposure to biological substances is prevented or controlled.

Yes No Not applicable

### Information

BIOLOGICAL HAZARDS

- What? Biological agents, i.e. microorganisms, cell cultures and parasites living in the human body, which may cause infections, allergies or poisoning. These microorganisms can penetrate the human body through a wound, an animal bite or needle injuries. They can also be inhaled or swallowed. There is a risk of viral and bacteriological infections such as HIV, hepatitis or tuberculosis, tetanus, legionella, …
- Who? All private security staff in specific work environments such as hospitals or with eventual biological risks.

Make sure the client informs you (the private security services company) and the private security guards about the risks and measures in place (e.g. required vaccinations).

### Resources

#### Legal references

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2000/54/EC Directive on the protection of workers from risks related to exposure to biological agents at work.

#### Additional resources

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Comments

Yes No Not applicable

### Information

BIOLOGICAL HAZARDS

- What? Biological agents, i.e. microorganisms, cell cultures and parasites living in the human body, which may cause infections, allergies or poisoning. These microorganisms can penetrate the human body through a wound, an animal bite or needle injuries. They can also be inhaled or swallowed. There is a risk of viral and bacteriological infections such as HIV, hepatitis or tuberculosis, tetanus, legionella, …
- Who? All private security staff in specific work environments such as hospitals or with eventual biological risks.

Make sure the client informs you (the private security services company) and the private security guards about the risks and measures in place (e.g. required vaccinations).

### Resources

#### Legal references

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2000/54/EC Directive on the protection of workers from risks related to exposure to biological agents at work.

#### Additional resources

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Comments
Scroll to top
Back

## 2014-01-08-exposure-to-biological-substances-is-prevented-or-controlled.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…